@@ -143,6 +143,12 @@ func (c *giteaClient) CreateFile(
 		},
 	}
 
+	log.
+		WithField("repository", repo.String()).
+		WithField("name", repo.Name).
+		WithField("name", repo.Name).
+		Info("pushing")
+
 	currentFile, resp, err := c.client.GetContents(repo.Owner, repo.Name, branch, path)
 	// file not exist, create it
 	if err != nil {
