@@ -9,9 +9,10 @@ import (
 	"reflect"
 	"strconv"
 	"strings"
+	"time"
 
 	"github.com/caarlos0/log"
-	"github.com/google/go-github/v50/github"
+	"github.com/google/go-github/v53/github"
 	"github.com/goreleaser/goreleaser/internal/artifact"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/config"
@@ -64,7 +65,22 @@ func newGitHub(ctx *context.Context, token string) (*githubClient, error) {
 	return &githubClient{client: client}, nil
 }
 
+func (c *githubClient) checkRateLimit(ctx *context.Context) {
+	limits, _, err := c.client.RateLimits(ctx)
+	if err != nil {
+		log.Warn("could not check rate limits, hoping for the best...")
+		return
+	}
+	if limits.Core.Remaining > 100 { // 100 should be safe enough
+		return
+	}
+	sleep := limits.Core.Reset.UTC().Sub(time.Now().UTC())
+	log.Warnf("token too close to rate limiting, will sleep for %s before continuing...", sleep)
+	time.Sleep(sleep)
+}
+
 func (c *githubClient) GenerateReleaseNotes(ctx *context.Context, repo Repo, prev, current string) (string, error) {
+	c.checkRateLimit(ctx)
 	notes, _, err := c.client.Repositories.GenerateReleaseNotes(ctx, repo.Owner, repo.Name, &github.GenerateNotesOptions{
 		TagName:         current,
 		PreviousTagName: github.String(prev),
@@ -76,6 +92,7 @@ func (c *githubClient) GenerateReleaseNotes(ctx *context.Context, repo Repo, pre
 }
 
 func (c *githubClient) Changelog(ctx *context.Context, repo Repo, prev, current string) (string, error) {
+	c.checkRateLimit(ctx)
 	var log []string
 	opts := &github.ListOptions{PerPage: 100}
 
@@ -103,6 +120,7 @@ func (c *githubClient) Changelog(ctx *context.Context, repo Repo, prev, current
 
 // getDefaultBranch returns the default branch of a github repo
 func (c *githubClient) getDefaultBranch(ctx *context.Context, repo Repo) (string, error) {
+	c.checkRateLimit(ctx)
 	p, res, err := c.client.Repositories.Get(ctx, repo.Owner, repo.Name)
 	if err != nil {
 		log.WithField("projectID", repo.String()).
@@ -116,6 +134,7 @@ func (c *githubClient) getDefaultBranch(ctx *context.Context, repo Repo) (string
 
 // CloseMilestone closes a given milestone.
 func (c *githubClient) CloseMilestone(ctx *context.Context, repo Repo, title string) error {
+	c.checkRateLimit(ctx)
 	milestone, err := c.getMilestoneByTitle(ctx, repo, title)
 	if err != nil {
 		return err
@@ -139,32 +158,76 @@ func (c *githubClient) CloseMilestone(ctx *context.Context, repo Repo, title str
 	return err
 }
 
+func headString(base, head Repo) string {
+	return strings.Join([]string{
+		firstNonEmpty(head.Owner, base.Owner),
+		firstNonEmpty(head.Name, base.Name),
+		firstNonEmpty(head.Branch, base.Branch),
+	}, ":")
+}
+
+func (c *githubClient) getPRTemplate(ctx *context.Context, repo Repo) (string, error) {
+	content, _, _, err := c.client.Repositories.GetContents(
+		ctx, repo.Owner, repo.Name,
+		".github/PULL_REQUEST_TEMPLATE.md",
+		&github.RepositoryContentGetOptions{
+			Ref: repo.Branch,
+		},
+	)
+	if err != nil {
+		return "", err
+	}
+	return content.GetContent()
+}
+
+const prFooter = "###### Automated with [GoReleaser](https://goreleaser.com)"
+
 func (c *githubClient) OpenPullRequest(
 	ctx *context.Context,
-	repo Repo,
-	base, title string,
+	base, head Repo,
+	title string,
+	draft bool,
 ) error {
-	if base == "" {
-		def, err := c.getDefaultBranch(ctx, repo)
+	c.checkRateLimit(ctx)
+	if base.Branch == "" {
+		def, err := c.getDefaultBranch(ctx, base)
 		if err != nil {
 			return err
 		}
-		base = def
+		base.Branch = def
 	}
-	pr, res, err := c.client.PullRequests.Create(ctx, repo.Owner, repo.Name, &github.NewPullRequest{
-		Title: github.String(title),
-		Head:  github.String(repo.Branch),
-		Base:  github.String(base),
-		Body:  github.String("Automatically generated by [GoReleaser](https://goreleaser.com)"),
-	})
+	tpl, err := c.getPRTemplate(ctx, base)
+	if err != nil {
+		log.WithError(err).Debug("no pull request template found...")
+	}
+	if len(tpl) > 0 {
+		log.Info("got a pr template")
+	}
+	log := log.
+		WithField("base", headString(base, Repo{})).
+		WithField("head", headString(base, head)).
+		WithField("draft", draft)
+	log.Info("opening pull request")
+	pr, res, err := c.client.PullRequests.Create(
+		ctx,
+		firstNonEmpty(base.Owner, head.Owner),
+		firstNonEmpty(base.Name, head.Name),
+		&github.NewPullRequest{
+			Title: github.String(title),
+			Base:  github.String(base.Branch),
+			Head:  github.String(headString(base, head)),
+			Body:  github.String(strings.Join([]string{tpl, prFooter}, "\n")),
+			Draft: github.Bool(draft),
+		},
+	)
 	if err != nil {
 		if res.StatusCode == 422 {
-			log.Warn("PR already exists, doing nothing...")
+			log.WithError(err).Warn("pull request validation failed")
 			return nil
 		}
 		return fmt.Errorf("could not create pull request: %w", err)
 	}
-	log.WithField("url", pr.GetHTMLURL()).Info("opened")
+	log.WithField("url", pr.GetHTMLURL()).Info("pull request created")
 	return nil
 }
 
@@ -176,6 +239,7 @@ func (c *githubClient) CreateFile(
 	path,
 	message string,
 ) error {
+	c.checkRateLimit(ctx)
 	defBranch, err := c.getDefaultBranch(ctx, repo)
 	if err != nil {
 		return fmt.Errorf("could not get default branch: %w", err)
@@ -201,6 +265,12 @@ func (c *githubClient) CreateFile(
 		options.Branch = &branch
 	}
 
+	log.
+		WithField("repository", repo.String()).
+		WithField("branch", repo.Branch).
+		WithField("file", path).
+		Info("pushing")
+
 	if defBranch != branch && branch != "" {
 		_, res, err := c.client.Repositories.GetBranch(ctx, repo.Owner, repo.Name, branch, true)
 		if err != nil && (res == nil || res.StatusCode != 404) {
@@ -251,6 +321,7 @@ func (c *githubClient) CreateFile(
 }
 
 func (c *githubClient) CreateRelease(ctx *context.Context, body string) (string, error) {
+	c.checkRateLimit(ctx)
 	title, err := tmpl.New(ctx).Apply(ctx.Config.Release.NameTemplate)
 	if err != nil {
 		return "", err
@@ -296,6 +367,7 @@ func (c *githubClient) CreateRelease(ctx *context.Context, body string) (string,
 }
 
 func (c *githubClient) createOrUpdateRelease(ctx *context.Context, data *github.RepositoryRelease, body string) (*github.RepositoryRelease, error) {
+	c.checkRateLimit(ctx)
 	release, _, err := c.client.Repositories.GetReleaseByTag(
 		ctx,
 		ctx.Config.Release.GitHub.Owner,
@@ -323,6 +395,7 @@ func (c *githubClient) createOrUpdateRelease(ctx *context.Context, data *github.
 }
 
 func (c *githubClient) updateRelease(ctx *context.Context, id int64, data *github.RepositoryRelease) (*github.RepositoryRelease, error) {
+	c.checkRateLimit(ctx)
 	release, resp, err := c.client.Repositories.EditRelease(
 		ctx,
 		ctx.Config.Release.GitHub.Owner,
@@ -359,6 +432,7 @@ func (c *githubClient) Upload(
 	artifact *artifact.Artifact,
 	file *os.File,
 ) error {
+	c.checkRateLimit(ctx)
 	githubReleaseID, err := strconv.ParseInt(releaseID, 10, 64)
 	if err != nil {
 		return err
@@ -394,6 +468,7 @@ func (c *githubClient) Upload(
 
 // getMilestoneByTitle returns a milestone by title.
 func (c *githubClient) getMilestoneByTitle(ctx *context.Context, repo Repo, title string) (*github.Milestone, error) {
+	c.checkRateLimit(ctx)
 	// The GitHub API/SDK does not provide lookup by title functionality currently.
 	opts := &github.MilestoneListOptions{
 		ListOptions: github.ListOptions{PerPage: 100},
@@ -456,6 +531,7 @@ func overrideGitHubClientAPI(ctx *context.Context, client *github.Client) error
 }
 
 func (c *githubClient) deleteExistingDraftRelease(ctx *context.Context, name string) error {
+	c.checkRateLimit(ctx)
 	opt := github.ListOptions{PerPage: 50}
 	for {
 		releases, resp, err := c.client.Repositories.ListReleases(
