@@ -26,6 +26,7 @@ type Mock struct {
 	CreatedFile          bool
 	Content              string
 	Path                 string
+	Message              string
 	FailToCreateRelease  bool
 	FailToUpload         bool
 	CreatedRelease       bool
@@ -42,7 +43,7 @@ type Mock struct {
 	OpenedPullRequest    bool
 }
 
-func (c *Mock) OpenPullRequest(_ *context.Context, _ Repo, _, _ string) error {
+func (c *Mock) OpenPullRequest(_ *context.Context, _, _ Repo, _ string, _ bool) error {
 	c.OpenedPullRequest = true
 	return nil
 }
@@ -84,10 +85,11 @@ func (c *Mock) ReleaseURLTemplate(_ *context.Context) (string, error) {
 	return "https://dummyhost/download/{{ .Tag }}/{{ .ArtifactName }}", nil
 }
 
-func (c *Mock) CreateFile(_ *context.Context, _ config.CommitAuthor, _ Repo, content []byte, path, _ string) error {
+func (c *Mock) CreateFile(_ *context.Context, _ config.CommitAuthor, _ Repo, content []byte, path, msg string) error {
 	c.CreatedFile = true
 	c.Content = string(content)
 	c.Path = path
+	c.Message = msg
 	return nil
 }
 
