@@ -32,12 +32,12 @@ func RunWithEnv(ctx context.Context, env []string, args ...string) (string, erro
 	cmd.Stderr = &stderr
 	cmd.Env = append(cmd.Env, env...)
 
-	log.WithField("args", args).Debug("running git")
 	err := cmd.Run()
 
-	log.WithField("stdout", stdout.String()).
-		WithField("stderr", stderr.String()).
-		Debug("git result")
+	log.WithField("args", args).
+		WithField("stdout", strings.TrimSpace(stdout.String())).
+		WithField("stderr", strings.TrimSpace(stderr.String())).
+		Debug("git command result")
 
 	if err != nil {
 		return "", errors.New(stderr.String())
@@ -59,3 +59,19 @@ func Clean(output string, err error) (string, error) {
 	}
 	return output, err
 }
+
+// CleanAllLines returns all the non empty lines of the output, cleaned up.
+func CleanAllLines(output string, err error) ([]string, error) {
+	var result []string
+	for _, line := range strings.Split(output, "\n") {
+		l := strings.TrimSpace(strings.ReplaceAll(line, "'", ""))
+		if l == "" {
+			continue
+		}
+		result = append(result, l)
+	}
+	if err != nil {
+		err = errors.New(strings.TrimSuffix(err.Error(), "\n"))
+	}
+	return result, err
+}
