@@ -42,11 +42,10 @@ func (Pipe) Run(ctx *context.Context) error {
 
 		var b bytes.Buffer
 		w := gio.Safe(&b)
-		fields := log.Fields{"hook": step}
 		cmd.Stderr = io.MultiWriter(logext.NewWriter(), w)
 		cmd.Stdout = io.MultiWriter(logext.NewWriter(), w)
 
-		log.WithFields(fields).Info("running")
+		log.WithField("hook", step).Info("running")
 		if err := cmd.Run(); err != nil {
 			return fmt.Errorf("hook failed: %s: %w; output: %s", step, err, b.String())
 		}
