@@ -60,11 +60,15 @@ func (ManifestPipe) Publish(ctx *context.Context) error {
 	for _, manifest := range ctx.Config.DockerManifests {
 		manifest := manifest
 		g.Go(func() error {
-			if strings.TrimSpace(manifest.SkipPush) == "true" {
+			skip, err := tmpl.New(ctx).Apply(manifest.SkipPush)
+			if err != nil {
+				return err
+			}
+			if strings.TrimSpace(skip) == "true" {
 				return pipe.Skip("docker_manifest.skip_push is set")
 			}
 
-			if strings.TrimSpace(manifest.SkipPush) == "auto" && ctx.Semver.Prerelease != "" {
+			if strings.TrimSpace(skip) == "auto" && ctx.Semver.Prerelease != "" {
 				return pipe.Skip("prerelease detected with 'auto' push, skipping docker manifest")
 			}
 
