@@ -20,6 +20,10 @@ import (
 	"github.com/stretchr/testify/require"
 )
 
+func TestContinueOnError(t *testing.T) {
+	require.True(t, Pipe{}.ContinueOnError())
+}
+
 func TestDescription(t *testing.T) {
 	require.NotEmpty(t, Pipe{}.String())
 }
@@ -138,8 +142,8 @@ func TestFullPipe(t *testing.T) {
 		"default": {
 			prepare: func(ctx *context.Context) {
 				ctx.TokenType = context.TokenTypeGitHub
-				ctx.Config.Krews[0].Index.Owner = "test"
-				ctx.Config.Krews[0].Index.Name = "test"
+				ctx.Config.Krews[0].Repository.Owner = "test"
+				ctx.Config.Krews[0].Repository.Name = "test"
 				ctx.Config.Krews[0].Homepage = "https://github.com/goreleaser"
 			},
 		},
@@ -147,7 +151,7 @@ func TestFullPipe(t *testing.T) {
 			prepare: func(ctx *context.Context) {
 				ctx.TokenType = context.TokenTypeGitHub
 				ctx.Config.Krews[0].Homepage = "https://github.com/goreleaser"
-				ctx.Config.Krews[0].Index = config.RepoRef{
+				ctx.Config.Krews[0].Repository = config.RepoRef{
 					Name:   "test",
 					Branch: "main",
 					Git: config.GitRepoRef{
@@ -160,63 +164,63 @@ func TestFullPipe(t *testing.T) {
 		"default_gitlab": {
 			prepare: func(ctx *context.Context) {
 				ctx.TokenType = context.TokenTypeGitLab
-				ctx.Config.Krews[0].Index.Owner = "test"
-				ctx.Config.Krews[0].Index.Name = "test"
+				ctx.Config.Krews[0].Repository.Owner = "test"
+				ctx.Config.Krews[0].Repository.Name = "test"
 				ctx.Config.Krews[0].Homepage = "https://gitlab.com/goreleaser"
 			},
 		},
 		"invalid_commit_template": {
 			prepare: func(ctx *context.Context) {
-				ctx.Config.Krews[0].Index.Owner = "test"
-				ctx.Config.Krews[0].Index.Name = "test"
+				ctx.Config.Krews[0].Repository.Owner = "test"
+				ctx.Config.Krews[0].Repository.Name = "test"
 				ctx.Config.Krews[0].CommitMessageTemplate = "{{ .Asdsa }"
 			},
 			expectedPublishError: `template: tmpl:1: unexpected "}" in operand`,
 		},
 		"invalid desc": {
 			prepare: func(ctx *context.Context) {
-				ctx.Config.Krews[0].Index.Owner = "test"
-				ctx.Config.Krews[0].Index.Name = "test"
+				ctx.Config.Krews[0].Repository.Owner = "test"
+				ctx.Config.Krews[0].Repository.Name = "test"
 				ctx.Config.Krews[0].Description = "{{ .Asdsa }"
 			},
 			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
 		},
 		"invalid short desc": {
 			prepare: func(ctx *context.Context) {
-				ctx.Config.Krews[0].Index.Owner = "test"
-				ctx.Config.Krews[0].Index.Name = "test"
+				ctx.Config.Krews[0].Repository.Owner = "test"
+				ctx.Config.Krews[0].Repository.Name = "test"
 				ctx.Config.Krews[0].ShortDescription = "{{ .Asdsa }"
 			},
 			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
 		},
 		"invalid homepage": {
 			prepare: func(ctx *context.Context) {
-				ctx.Config.Krews[0].Index.Owner = "test"
-				ctx.Config.Krews[0].Index.Name = "test"
+				ctx.Config.Krews[0].Repository.Owner = "test"
+				ctx.Config.Krews[0].Repository.Name = "test"
 				ctx.Config.Krews[0].Homepage = "{{ .Asdsa }"
 			},
 			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
 		},
 		"invalid name": {
 			prepare: func(ctx *context.Context) {
-				ctx.Config.Krews[0].Index.Owner = "test"
-				ctx.Config.Krews[0].Index.Name = "test"
+				ctx.Config.Krews[0].Repository.Owner = "test"
+				ctx.Config.Krews[0].Repository.Name = "test"
 				ctx.Config.Krews[0].Name = "{{ .Asdsa }"
 			},
 			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
 		},
 		"invalid caveats": {
 			prepare: func(ctx *context.Context) {
-				ctx.Config.Krews[0].Index.Owner = "test"
-				ctx.Config.Krews[0].Index.Name = "test"
+				ctx.Config.Krews[0].Repository.Owner = "test"
+				ctx.Config.Krews[0].Repository.Name = "test"
 				ctx.Config.Krews[0].Caveats = "{{ .Asdsa }"
 			},
 			expectedRunError: `template: tmpl:1: unexpected "}" in operand`,
 		},
 		"no short desc": {
 			prepare: func(ctx *context.Context) {
-				ctx.Config.Krews[0].Index.Owner = "test"
-				ctx.Config.Krews[0].Index.Name = "test"
+				ctx.Config.Krews[0].Repository.Owner = "test"
+				ctx.Config.Krews[0].Repository.Name = "test"
 				ctx.Config.Krews[0].Description = "lalala"
 				ctx.Config.Krews[0].ShortDescription = ""
 			},
@@ -224,8 +228,8 @@ func TestFullPipe(t *testing.T) {
 		},
 		"no desc": {
 			prepare: func(ctx *context.Context) {
-				ctx.Config.Krews[0].Index.Owner = "test"
-				ctx.Config.Krews[0].Index.Name = "test"
+				ctx.Config.Krews[0].Repository.Owner = "test"
+				ctx.Config.Krews[0].Repository.Name = "test"
 				ctx.Config.Krews[0].Description = ""
 				ctx.Config.Krews[0].ShortDescription = "lalala"
 			},
@@ -297,7 +301,7 @@ func TestFullPipe(t *testing.T) {
 			require.NoError(t, err)
 			require.NoError(t, f.Close())
 			client := client.NewMock()
-			distFile := filepath.Join(folder, name+".yaml")
+			distFile := filepath.Join(folder, "krew", name+".yaml")
 
 			require.NoError(t, Pipe{}.Default(ctx))
 			err = runAll(ctx, client)
@@ -316,7 +320,7 @@ func TestFullPipe(t *testing.T) {
 			require.NoError(t, err)
 
 			content := []byte(client.Content)
-			if url := ctx.Config.Krews[0].Index.Git.URL; url == "" {
+			if url := ctx.Config.Krews[0].Repository.Git.URL; url == "" {
 				require.True(t, client.CreatedFile, "should have created a file")
 			} else {
 				content = testlib.CatFileFromBareRepository(t, url, "plugins/"+name+".yaml")
@@ -344,7 +348,7 @@ func TestRunPipePullRequest(t *testing.T) {
 					Homepage:         "https://goreleaser.com",
 					ShortDescription: "test",
 					Description:      "Fake desc",
-					Index: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner:  "foo",
 						Name:   "bar",
 						Branch: "update-{{.Version}}",
@@ -397,7 +401,7 @@ func TestRunPipeUniversalBinary(t *testing.T) {
 					Name:             manifestName(t),
 					Description:      "Some desc",
 					ShortDescription: "Short desc",
-					Index: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "unibin",
 						Name:  "bar",
 					},
@@ -430,7 +434,7 @@ func TestRunPipeUniversalBinary(t *testing.T) {
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
 	client := client.NewMock()
-	distFile := filepath.Join(folder, manifestName(t)+".yaml")
+	distFile := filepath.Join(folder, "krew", manifestName(t)+".yaml")
 
 	require.NoError(t, runAll(ctx, client))
 	require.NoError(t, publishAll(ctx, client))
@@ -453,7 +457,7 @@ func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 					Name:             manifestName(t),
 					Description:      "Some desc",
 					ShortDescription: "Short desc",
-					Index: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "unibin",
 						Name:  "bar",
 					},
@@ -511,7 +515,7 @@ func TestRunPipeUniversalBinaryNotReplacing(t *testing.T) {
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
 	client := client.NewMock()
-	distFile := filepath.Join(folder, manifestName(t)+".yaml")
+	distFile := filepath.Join(folder, "krew", manifestName(t)+".yaml")
 
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.NoError(t, runAll(ctx, client))
@@ -535,7 +539,7 @@ func TestRunPipeNameTemplate(t *testing.T) {
 					Name:             "{{ .Env.FOO_BAR }}",
 					Description:      "Some desc",
 					ShortDescription: "Short desc",
-					Index: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "foo",
 						Name:  "bar",
 					},
@@ -568,7 +572,7 @@ func TestRunPipeNameTemplate(t *testing.T) {
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
 	client := client.NewMock()
-	distFile := filepath.Join(folder, t.Name()+".yaml")
+	distFile := filepath.Join(folder, "krew", t.Name()+".yaml")
 
 	require.NoError(t, Pipe{}.Default(ctx))
 	require.NoError(t, runAll(ctx, client))
@@ -592,7 +596,7 @@ func TestRunPipeMultipleKrewWithSkip(t *testing.T) {
 					Name:             "foo",
 					Description:      "Some desc",
 					ShortDescription: "Short desc",
-					Index: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "foo",
 						Name:  "bar",
 					},
@@ -605,7 +609,7 @@ func TestRunPipeMultipleKrewWithSkip(t *testing.T) {
 					Name:             "bar",
 					Description:      "Some desc",
 					ShortDescription: "Short desc",
-					Index: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "foo",
 						Name:  "bar",
 					},
@@ -617,7 +621,7 @@ func TestRunPipeMultipleKrewWithSkip(t *testing.T) {
 					Name:             "foobar",
 					Description:      "Some desc",
 					ShortDescription: "Short desc",
-					Index: config.RepoRef{
+					Repository: config.RepoRef{
 						Owner: "foo",
 						Name:  "bar",
 					},
@@ -658,7 +662,7 @@ func TestRunPipeMultipleKrewWithSkip(t *testing.T) {
 	require.True(t, cli.CreatedFile)
 
 	for _, manifest := range ctx.Config.Krews {
-		distFile := filepath.Join(folder, manifest.Name+".yaml")
+		distFile := filepath.Join(folder, "krew", manifest.Name+".yaml")
 		_, err := os.Stat(distFile)
 		require.NoError(t, err, "file should exist: "+distFile)
 	}
@@ -687,7 +691,7 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 							Name:             name,
 							ShortDescription: "Short desc",
 							Description:      "A run pipe test krew manifest and FOO={{ .Env.FOO }}",
-							Index: config.RepoRef{
+							Repository: config.RepoRef{
 								Owner: "test",
 								Name:  "test",
 							},
@@ -766,7 +770,7 @@ func TestRunPipeForMultipleArmVersions(t *testing.T) {
 			}
 
 			client := client.NewMock()
-			distFile := filepath.Join(folder, name+".yaml")
+			distFile := filepath.Join(folder, "krew", name+".yaml")
 
 			require.NoError(t, Pipe{}.Default(ctx))
 			require.NoError(t, runAll(ctx, client))
@@ -789,7 +793,7 @@ func TestRunPipeNoBuilds(t *testing.T) {
 				Name:             manifestName(t),
 				Description:      "Some desc",
 				ShortDescription: "Short desc",
-				Index: config.RepoRef{
+				Repository: config.RepoRef{
 					Owner: "test",
 					Name:  "test",
 				},
@@ -812,7 +816,7 @@ func TestRunPipeNoUpload(t *testing.T) {
 				Name:             manifestName(t),
 				Description:      "Some desc",
 				ShortDescription: "Short desc",
-				Index: config.RepoRef{
+				Repository: config.RepoRef{
 					Owner: "test",
 					Name:  "test",
 				},
@@ -868,7 +872,7 @@ func TestRunEmptyTokenType(t *testing.T) {
 				Name:             manifestName(t),
 				Description:      "Some desc",
 				ShortDescription: "Short desc",
-				Index: config.RepoRef{
+				Repository: config.RepoRef{
 					Owner: "test",
 					Name:  "test",
 				},
@@ -908,7 +912,7 @@ func TestRunMultipleBinaries(t *testing.T) {
 				Name:             manifestName(t),
 				Description:      "Some desc",
 				ShortDescription: "Short desc",
-				Index: config.RepoRef{
+				Repository: config.RepoRef{
 					Owner: "test",
 					Name:  "test",
 				},
@@ -943,7 +947,13 @@ func TestDefault(t *testing.T) {
 	ctx := testctx.NewWithCfg(config.Project{
 		ProjectName: "myproject",
 		Krews: []config.Krew{
-			{},
+			{
+				Index: config.RepoRef{
+					Git: config.GitRepoRef{
+						URL: "foo/bar",
+					},
+				},
+			},
 		},
 	}, testctx.GitHubTokenType)
 	require.NoError(t, Pipe{}.Default(ctx))
@@ -951,6 +961,8 @@ func TestDefault(t *testing.T) {
 	require.NotEmpty(t, ctx.Config.Krews[0].CommitAuthor.Name)
 	require.NotEmpty(t, ctx.Config.Krews[0].CommitAuthor.Email)
 	require.NotEmpty(t, ctx.Config.Krews[0].CommitMessageTemplate)
+	require.Equal(t, "foo/bar", ctx.Config.Krews[0].Repository.Git.URL)
+	require.True(t, ctx.Deprecated)
 }
 
 func TestGHFolder(t *testing.T) {
