@@ -1,4 +1,4 @@
-// Package scoop provides a Pipe that generates a scoop.sh App Manifest and pushes it to a bucket
+// Package scoop provides a Pipe that generates a scoop.sh App Manifest and pushes it to a bucket.
 package scoop
 
 import (
@@ -8,6 +8,7 @@ import (
 	"os"
 	"path"
 	"path/filepath"
+	"reflect"
 	"strings"
 
 	"github.com/caarlos0/log"
@@ -58,9 +59,10 @@ const scoopConfigExtra = "ScoopConfig"
 // Pipe that builds and publishes scoop manifests.
 type Pipe struct{}
 
-func (Pipe) String() string { return "scoop manifests" }
+func (Pipe) String() string        { return "scoop manifests" }
+func (Pipe) ContinueOnError() bool { return true }
 func (Pipe) Skip(ctx *context.Context) bool {
-	return ctx.Config.Scoop.Bucket.Name == "" && len(ctx.Config.Scoops) == 0
+	return ctx.Config.Scoop.Repository.Name == "" && len(ctx.Config.Scoops) == 0
 }
 
 // Run creates the scoop manifest locally.
@@ -83,7 +85,8 @@ func (Pipe) Publish(ctx *context.Context) error {
 
 // Default sets the pipe defaults.
 func (Pipe) Default(ctx *context.Context) error {
-	if ctx.Config.Scoop.Bucket.Name != "" {
+	if !reflect.DeepEqual(ctx.Config.Scoop.Bucket, config.RepoRef{}) ||
+		!reflect.DeepEqual(ctx.Config.Scoop.Repository, config.RepoRef{}) {
 		deprecate.Notice(ctx, "scoop")
 		ctx.Config.Scoops = append(ctx.Config.Scoops, ctx.Config.Scoop)
 	}
@@ -99,6 +102,10 @@ func (Pipe) Default(ctx *context.Context) error {
 		if scoop.Goamd64 == "" {
 			scoop.Goamd64 = "v1"
 		}
+		if !reflect.DeepEqual(scoop.Bucket, config.RepoRef{}) {
+			scoop.Repository = scoop.Bucket
+			deprecate.Notice(ctx, "scoops.bucket")
+		}
 	}
 	return nil
 }
@@ -143,7 +150,35 @@ func doRun(ctx *context.Context, scoop config.Scoop, cl client.ReleaserURLTempla
 		return ErrIncorrectArchiveCount{scoop.Goamd64, scoop.IDs, archives}
 	}
 
-	filename := scoop.Name + ".json"
+	name, err := tmpl.New(ctx).Apply(scoop.Name)
+	if err != nil {
+		return err
+	}
+	scoop.Name = name
+
+	description, err := tmpl.New(ctx).Apply(scoop.Description)
+	if err != nil {
+		return err
+	}
+	scoop.Description = description
+
+	homepage, err := tmpl.New(ctx).Apply(scoop.Homepage)
+	if err != nil {
+		return err
+	}
+	scoop.Homepage = homepage
+
+	ref, err := client.TemplateRef(tmpl.New(ctx).Apply, scoop.Repository)
+	if err != nil {
+		return err
+	}
+	scoop.Repository = ref
+
+	skipUpload, err := tmpl.New(ctx).Apply(scoop.SkipUpload)
+	if err != nil {
+		return err
+	}
+	scoop.SkipUpload = skipUpload
 
 	data, err := dataFor(ctx, scoop, cl, archives)
 	if err != nil {
@@ -154,7 +189,11 @@ func doRun(ctx *context.Context, scoop config.Scoop, cl client.ReleaserURLTempla
 		return err
 	}
 
-	path := filepath.Join(ctx.Config.Dist, filename)
+	filename := scoop.Name + ".json"
+	path := filepath.Join(ctx.Config.Dist, "scoop", scoop.Folder, filename)
+	if err := os.MkdirAll(filepath.Dir(path), 0o755); err != nil {
+		return err
+	}
 	log.WithField("manifest", path).Info("writing")
 	if err := os.WriteFile(path, content.Bytes(), 0o644); err != nil {
 		return fmt.Errorf("failed to write scoop manifest: %w", err)
@@ -172,8 +211,9 @@ func doRun(ctx *context.Context, scoop config.Scoop, cl client.ReleaserURLTempla
 }
 
 func publishAll(ctx *context.Context, cli client.Client) error {
-	// even if one of them skips, we run them all, and then show return the skips all at once.
-	// this is needed so we actually create the `dist/foo.rb` file, which is useful for debugging.
+	// even if one of them skips, we run them all, and then show return the
+	// skips all at once. this is needed so we actually create the
+	// `dist/foo.json` file, which is useful for debugging.
 	skips := pipe.SkipMemento{}
 	for _, manifest := range ctx.Artifacts.Filter(artifact.ByType(artifact.ScoopManifest)).List() {
 		err := doPublish(ctx, manifest, cli)
@@ -201,14 +241,6 @@ func doPublish(ctx *context.Context, manifest *artifact.Artifact, cl client.Clie
 		return pipe.Skip("release is prerelease")
 	}
 
-	relDisabled, err := tmpl.New(ctx).Bool(ctx.Config.Release.Disable)
-	if err != nil {
-		return err
-	}
-	if relDisabled {
-		return pipe.Skip("release is disabled")
-	}
-
 	commitMessage, err := tmpl.New(ctx).Apply(scoop.CommitMessageTemplate)
 	if err != nil {
 		return err
@@ -224,26 +256,20 @@ func doPublish(ctx *context.Context, manifest *artifact.Artifact, cl client.Clie
 		return err
 	}
 
-	ref, err := client.TemplateRef(tmpl.New(ctx).Apply, scoop.Bucket)
-	if err != nil {
-		return err
-	}
-	scoop.Bucket = ref
-
-	repo := client.RepoFromRef(scoop.Bucket)
+	repo := client.RepoFromRef(scoop.Repository)
 	gpath := path.Join(scoop.Folder, manifest.Name)
 
-	if scoop.Bucket.Git.URL != "" {
+	if scoop.Repository.Git.URL != "" {
 		return client.NewGitUploadClient(repo.Branch).
 			CreateFile(ctx, author, repo, content, gpath, commitMessage)
 	}
 
-	cl, err = client.NewIfToken(ctx, cl, scoop.Bucket.Token)
+	cl, err = client.NewIfToken(ctx, cl, scoop.Repository.Token)
 	if err != nil {
 		return err
 	}
 
-	if !scoop.Bucket.PullRequest.Enabled {
+	if !scoop.Repository.PullRequest.Enabled {
 		return cl.CreateFile(ctx, author, repo, content, gpath, commitMessage)
 	}
 
@@ -257,8 +283,11 @@ func doPublish(ctx *context.Context, manifest *artifact.Artifact, cl client.Clie
 		return err
 	}
 
-	title := fmt.Sprintf("Updated %s to %s", ctx.Config.ProjectName, ctx.Version)
-	return pcl.OpenPullRequest(ctx, repo, scoop.Bucket.PullRequest.Base, title)
+	return pcl.OpenPullRequest(ctx, client.Repo{
+		Name:   scoop.Repository.PullRequest.Base.Name,
+		Owner:  scoop.Repository.PullRequest.Base.Owner,
+		Branch: scoop.Repository.PullRequest.Base.Branch,
+	}, repo, commitMessage, scoop.Repository.PullRequest.Draft)
 }
 
 // Manifest represents a scoop.sh App Manifest.
