@@ -1,4 +1,4 @@
-// Package pipeline provides generic erros for pipes to use.
+// Package pipeline provides generic errors for pipes to use.
 package pipeline
 
 import (
@@ -23,6 +23,7 @@ import (
 	"github.com/goreleaser/goreleaser/internal/pipe/krew"
 	"github.com/goreleaser/goreleaser/internal/pipe/metadata"
 	"github.com/goreleaser/goreleaser/internal/pipe/nfpm"
+	"github.com/goreleaser/goreleaser/internal/pipe/nix"
 	"github.com/goreleaser/goreleaser/internal/pipe/prebuild"
 	"github.com/goreleaser/goreleaser/internal/pipe/publish"
 	"github.com/goreleaser/goreleaser/internal/pipe/reportsizes"
@@ -35,6 +36,7 @@ import (
 	"github.com/goreleaser/goreleaser/internal/pipe/sourcearchive"
 	"github.com/goreleaser/goreleaser/internal/pipe/universalbinary"
 	"github.com/goreleaser/goreleaser/internal/pipe/upx"
+	"github.com/goreleaser/goreleaser/internal/pipe/winget"
 	"github.com/goreleaser/goreleaser/pkg/context"
 )
 
@@ -109,6 +111,10 @@ var Pipeline = append(
 	sign.Pipe{},
 	// create arch linux aur pkgbuild
 	aur.Pipe{},
+	// create nixpkgs
+	nix.NewBuild(),
+	// winget installers
+	winget.Pipe{},
 	// create brew tap
 	brew.Pipe{},
 	// krew plugins
@@ -122,7 +128,7 @@ var Pipeline = append(
 	// create and push docker images
 	docker.Pipe{},
 	// publishes artifacts
-	publish.Pipe{},
+	publish.New(),
 	// creates a metadata.json and an artifacts.json files in the dist folder
 	metadata.Pipe{},
 	// announce releases
