@@ -51,6 +51,7 @@ const (
 	patch           = "Patch"
 	prerelease      = "Prerelease"
 	isSnapshot      = "IsSnapshot"
+	isNightly       = "IsNightly"
 	isDraft         = "IsDraft"
 	env             = "Env"
 	date            = "Date"
@@ -109,6 +110,7 @@ func New(ctx *context.Context) *Template {
 		patch:           ctx.Semver.Patch,
 		prerelease:      ctx.Semver.Prerelease,
 		isSnapshot:      ctx.Snapshot,
+		isNightly:       false,
 		isDraft:         ctx.Config.Release.Draft,
 		releaseNotes:    ctx.ReleaseNotes,
 		releaseURL:      ctx.ReleaseURL,
@@ -154,22 +156,6 @@ func (t *Template) WithExtraFields(f Fields) *Template {
 	return t
 }
 
-// WithArtifactReplacements populates Fields from the artifact and replacements.
-//
-// Deprecated: use WithArtifact instead.
-func (t *Template) WithArtifactReplacements(a *artifact.Artifact, replacements map[string]string) *Template {
-	t.fields[osKey] = replace(replacements, a.Goos)
-	t.fields[arch] = replace(replacements, a.Goarch)
-	t.fields[arm] = replace(replacements, a.Goarm)
-	t.fields[mips] = replace(replacements, a.Gomips)
-	t.fields[amd64] = replace(replacements, a.Goamd64)
-	t.fields[binary] = artifact.ExtraOr(*a, binary, t.fields[projectName].(string))
-	t.fields[artifactName] = a.Name
-	t.fields[artifactExt] = artifact.ExtraOr(*a, artifact.ExtraExt, "")
-	t.fields[artifactPath] = a.Path
-	return t
-}
-
 // WithArtifact populates Fields from the artifact.
 func (t *Template) WithArtifact(a *artifact.Artifact) *Template {
 	t.fields[osKey] = a.Goos
@@ -232,6 +218,8 @@ func (t *Template) Apply(s string) (string, error) {
 			"incpatch":      incPatch,
 			"filter":        filter(false),
 			"reverseFilter": filter(true),
+			"mdv2escape":    mdv2Escape,
+			"envOrDefault":  t.envOrDefault,
 		}).
 		Parse(s)
 	if err != nil {
@@ -242,6 +230,14 @@ func (t *Template) Apply(s string) (string, error) {
 	return out.String(), err
 }
 
+func (t *Template) envOrDefault(name, value string) string {
+	s, ok := t.fields[env].(context.Env)[name]
+	if !ok {
+		return value
+	}
+	return s
+}
+
 type ExpectedSingleEnvErr struct{}
 
 func (e ExpectedSingleEnvErr) Error() string {
@@ -277,15 +273,6 @@ func (t *Template) ApplySingleEnvOnly(s string) (string, error) {
 	return out.String(), err
 }
 
-// deprecated: will be removed soon.
-func replace(replacements map[string]string, original string) string {
-	result := replacements[original]
-	if result == "" {
-		return original
-	}
-	return result
-}
-
 func incMajor(v string) string {
 	return prefix(v) + semver.MustParse(v).IncMajor().String()
 }
@@ -322,3 +309,26 @@ func filter(reverse bool) func(content, exp string) string {
 		return strings.Join(lines, "\n")
 	}
 }
+
+func mdv2Escape(s string) string {
+	return strings.NewReplacer(
+		"_", "\\_",
+		"*", "\\*",
+		"[", "\\[",
+		"]", "\\]",
+		"(", "\\(",
+		")", "\\)",
+		"~", "\\~",
+		"`", "\\`",
+		">", "\\>",
+		"#", "\\#",
+		"+", "\\+",
+		"-", "\\-",
+		"=", "\\=",
+		"|", "\\|",
+		"{", "\\{",
+		"}", "\\}",
+		".", "\\.",
+		"!", "\\!",
+	).Replace(s)
+}
